@@ -11,14 +11,17 @@ from ._py_op_commands import (
 from ._py_op_deprecation import deprecated_kwargs
 from .account import OPAccountList
 from .op_items._item_list import OPItemList
+from .op_items._item_type_registry import OPItemFactory
 from .op_items._new_item import OPNewItemMixin
-from .op_items._op_item_type_registry import OPItemFactory
-from .op_items._op_items_base import OPAbstractItem
-from .op_items.generic_item import (
+from .op_items.item_types._item_base import OPAbstractItem
+from .op_items.item_types.generic_item import (
     _OPGenericItem,
     _OPGenericItemRelaxedValidation
 )
-from .op_items.login import OPLoginItemNewPrimaryURL, OPLoginItemTemplate
+from .op_items.item_types.login import (
+    OPLoginItemNewPrimaryURL,
+    OPLoginItemTemplate
+)
 from .op_items.password_recipe import OPPasswordRecipe
 from .op_items.totp import OPTOTPItem
 from .op_objects import (
@@ -596,7 +599,7 @@ class OP(_OPCommandInterface, PyOPAboutMixin):
     #   There is ongoing work in mock-op and mock-cli-framework to simulate changed state
     #   when this is complete these functions need to be tested
     #
-    #   For now, ignore testing coverate
+    #   For now, ignore testing coverage
     def item_create(self,
                     new_item: OPNewItemMixin,
                     password_recipe: OPPasswordRecipe = None,
