@@ -6,8 +6,8 @@ import pytest
 
 from pyonepassword.api.exceptions import OPSectionNotFoundException
 from pyonepassword.api.object_types import OPLoginItem
-from pyonepassword.op_items.item_field_base import OPItemField
-from pyonepassword.op_items.item_section import OPSection
+from pyonepassword.op_items.fields_sections.item_field_base import OPItemField
+from pyonepassword.op_items.fields_sections.item_section import OPSection
 
 if TYPE_CHECKING:
     from .fixtures.expected_item_fields import ExpectedItemField
@@ -77,7 +77,7 @@ def test_item_section_02(valid_data: ValidData, expected_login_item_data: Expect
     """
     item_name = "Example Login with Fields"
     section_id = "vh4wk7qyw46urc7wuwczzhpm7u"
-    field_label = "EXAMPLE FIELD"
+    field_label = "Example Field"
     field_id = "ikr76mnggw767qwqoel624oqv4"
     expected_login: ExpectedLogin = expected_login_item_data.data_for_login(
         item_name)
